@@ -7,6 +7,8 @@ import os
 import log_convert
 from datetime import datetime
 
+version = "0.7.3"
+
 
 class ViewForm(npyscreen.Form):
     def __init__(self, name, outer_instance):
@@ -213,8 +215,15 @@ def main():
     parser.add_argument("-o", "--outfile", help="Output log filename")
     parser.add_argument("-r", "--rigserver", help="Rigctld server address")
     parser.add_argument("-p", "--rigport", help="Rigctld server port")
+    parser.add_argument(
+        "-v", "--version", action="store_true", help="Print Version"
+    )
     args = parser.parse_args()
 
+    if args.version:
+        print(version)
+        sys.exit(0)
+
     def chkswp(logfile):
         if os.path.isfile(logfile + ".swp"):
             return True
